@@ -339,7 +339,8 @@ totem_embedded_set_state (TotemEmbedded *emb, TotemStates state)
 		break;
 	}
 
-	totem_scrsaver_set_state (emb->scrsaver, (state == STATE_PLAYING) ? FALSE : TRUE);
+	if (emb->scrsaver != NULL)
+		totem_scrsaver_set_state (emb->scrsaver, (state == STATE_PLAYING) ? FALSE : TRUE);
 	gtk_image_set_from_stock (GTK_IMAGE (image), id, GTK_ICON_SIZE_MENU);
 	gtk_tool_button_set_stock_id (GTK_TOOL_BUTTON (emb->pp_fs_button), id);
 
@@ -951,6 +952,9 @@ totem_embedded_open_stream (TotemEmbedded *emb,
 	bacon_video_widget_close (emb->bvw);
 
 	totem_embedded_set_uri (emb, uri, base_uri, TRUE);
+	/* We can only have one item in the "playlist" when
+	 * we open a browser stream */
+	emb->num_items = 1;
 
 	/* FIXME: consume any remaining input from stdin */
 
