@@ -416,8 +416,15 @@ totem_action_seek (Totem *totem, double pos)
 		msg = g_strdup_printf(_("Totem could not play '%s'."), disp);
 		g_free (disp);
 
-		totem_action_error (msg, err->message, totem);
+		/* Release the lock and reset everything so that we
+		 * avoid being "stuck" seeking */
+		totem_statusbar_set_seeking (TOTEM_STATUSBAR (totem->statusbar), FALSE);
+		totem_time_label_set_seeking (TOTEM_TIME_LABEL (totem->fs->time_label), FALSE);
+		totem->seek_lock = FALSE;
+		bacon_video_widget_seek (totem->bvw, 0, NULL);
 		totem_action_stop (totem);
+
+		totem_action_error (msg, err->message, totem);
 		g_free (msg);
 		g_error_free (err);
 	}
@@ -1618,9 +1625,7 @@ seek_slider_released_cb (GtkWidget *widget, GdkEventButton *event, Totem *totem)
 	val = gtk_adjustment_get_value (adj);
 
 	if (bacon_video_widget_can_direct_seek (totem->bvw) == FALSE)
-	{
 		totem_action_seek (totem, val / 65535.0);
-	}
 
 	totem_statusbar_set_seeking (TOTEM_STATUSBAR (totem->statusbar), FALSE);
 	totem_time_label_set_seeking (TOTEM_TIME_LABEL (totem->fs->time_label),
@@ -3014,18 +3019,6 @@ totem_message_connection_receive_cb (const char *msg, Totem *totem)
 	g_free (url);
 }
 
-GtkWidget *
-totem_volume_create (void)
-{
-	GtkWidget *widget;
-
-	widget = gtk_volume_button_new ();
-	gtk_widget_set_sensitive (widget, FALSE);
-	gtk_widget_show (widget);
-
-	return widget;
-}
-
 int
 main (int argc, char **argv)
 {
